Learn R Programming

bscui (version 0.1.6)

bscui-shiny: 'shiny' bindings for bscui

Description

Output and render functions for using bscui within 'shiny' applications.

Usage

bscuiOutput(outputId, width = "100%", height = "400px")

renderBscui(expr, env = parent.frame(), quoted = FALSE)

Value

An output or render function that enables the use of the widget within 'shiny' applications.

Arguments

outputId

output variable to read from

width, height

Must be a valid CSS unit (like '100\%', '400px', 'auto') or a number, which will be coerced to a string and have 'px' appended.

expr

An expression that generates a bscui

env

The environment in which to evaluate expr.

quoted

Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.

Details

The bscuiProxy() function can be used to allow user interface dynamic updates.

See Also

bscuiProxy()

Examples

Run this code
if(interactive()){
   from_shiny <- new.env()
   shiny::runApp(system.file(
      "examples", "shiny-anatomogram", package = "bscui"
   ))
   for(n in names(from_shiny)){
      bscui(from_shiny[[n]]) |> print()
   }
}

Run the code above in your browser using DataLab